@@ -2,7 +2,7 @@
 from pathlib import Path
 from sphinx.util import logging
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 logger = logging.getLogger(__name__)
 
@@ -40,7 +40,19 @@ def add_to_context(app, config):
     config.html_context.update(
         {"copybutton_here_doc_delimiter": config.copybutton_here_doc_delimiter}
     )
-    config.html_context.update({"copybutton_image_path": config.copybutton_image_path})
+
+    # Old image path deprecation
+    # REMOVE after next release
+    if config.copybutton_image_path:
+        path = Path(app.srcdir) / config.copybutton_image_path
+        logger.warning("copybutton_image_path is deprecated, use copybutton_image_svg")
+        if not path.exists():
+            raise ValueError("copybutton_img_path does not exist")
+        if not path.suffix == ".svg":
+            raise ValueError("copybutton_img_path must be an SVG")
+        config.copybutton_image_svg = path.read_text()
+
+    config.html_context.update({"copybutton_image_svg": config.copybutton_image_svg})
     config.html_context.update({"copybutton_selector": config.copybutton_selector})
     config.html_context.update(
         {
@@ -66,14 +78,18 @@ def setup(app):
     app.add_config_value("copybutton_copy_empty_lines", True, "html")
     app.add_config_value("copybutton_line_continuation_character", "", "html")
     app.add_config_value("copybutton_here_doc_delimiter", "", "html")
-    app.add_config_value("copybutton_image_path", "copy-button.svg", "html")
+    app.add_config_value("copybutton_image_svg", "", "html")
     app.add_config_value("copybutton_selector", "div.highlight pre", "html")
 
+    # DEPRECATE THIS AFTER THE NEXT RELEASE
+    app.add_config_value("copybutton_image_path", "", "html")
+
     # Add configuration value to the template
     app.connect("config-inited", add_to_context)
 
     # Add relevant code to headers
     app.add_css_file("copybutton.css")
+    app.add_js_file("clipboard.min.js")
     app.add_js_file("copybutton.js")
     return {
         "version": __version__,
